@@ -1,4 +1,4 @@
-## $Id: length-methods.R 430 2011-03-05 09:23:32Z sgibb $
+## $Id: length-methods.R 562 2011-05-26 08:56:09Z sgibb $
 ##
 ## Copyright 2011 Sebastian Gibb
 ## <mail@sebastiangibb.de>
@@ -18,10 +18,11 @@
 ## You should have received a copy of the GNU General Public License
 ## along with MALDIquant. If not, see <http://www.gnu.org/licenses/>
 
-## AbstractSpectrumData 
+## AbstractMassSpectrumData 
 setMethod(f="length",
-    signature=signature(x="AbstractSpectrumData"),
+    signature=signature(x="AbstractMassSpectrumData"),
     definition=function(x) {
     
     return(length(x@intensity));
 });
+
