@@ -1,4 +1,4 @@
-## $Id: lines-methods.R 446 2011-03-10 16:44:59Z sgibb $
+## $Id: lines-methods.R 562 2011-05-26 08:56:09Z sgibb $
 ##
 ## Copyright 2011 Sebastian Gibb
 ## <mail@sebastiangibb.de>
@@ -18,11 +18,11 @@
 ## You should have received a copy of the GNU General Public License
 ## along with MALDIquant. If not, see <http://www.gnu.org/licenses/>
 
-## AbstractSpectrumData 
+## AbstractMassSpectrumData 
 setMethod(f="lines", 
-    signature=signature(x="AbstractSpectrumData"),
+    signature=signature(x="AbstractMassSpectrumData"),
     definition=function(x, 
-        type=ifelse(is(object=x, class2="SinglePeakList"), "h", "l"),
+        type=ifelse(is(object=x, class2="MassPeaks"), "h", "l"),
         ...) {
 
     lines(x=x@mass, y=x@intensity, type, ...);
